@@ -83,6 +83,7 @@ error_reporting(error_reporting()&~E_NOTICE);
  * @global object $App Application object
  */
 $App = new Application($configfile,$_REQUEST,$MODULE);
+$ACCESS_LEVEL = $App->accessLevel();
 
 
 function eor ()
@@ -148,7 +149,7 @@ if (! $CURRENT_ACTION || ! preg_match('/^[a-zA-Z0-9_-]+$/',$CURRENT_ACTION)) {
     $CURRENT_ACTION = $default_action;
 }
 
-$App->log("CA $CURRENT_ACTION",2,'SPAF2');
+$App->log("CA[$ACCESS_LEVEL] $CURRENT_ACTION",2,'SPAF2');
 $App->view = $CURRENT_ACTION;
 
 $tmpAccess = $App->getSession('tmpAccess');
@@ -178,7 +179,7 @@ if (file_exists($SP_FILE)) {
     }
     else {
         // authzError
-        $App->log("ERR_AUTHZ $SP_FILE",1,'SPAF2');
+        $App->log("ERR_AUTHZ[$ACCESS_LEVEL] $SP_FILE",1,'SPAF2');
         $App->view = 'error';
     }
 }
@@ -195,7 +196,7 @@ if (file_exists($MODULE.'/post_ctrl.php')) {
  * controller will not checked for authorization.
  *
  */
-$App->log("VIEW ".$App->view,2,'SPAF2');
+$App->log("VIEW[$ACCESS_LEVEL]) ".$App->view,2,'SPAF2');
 // check if file exists or call default view file. The default view
 // will not checked for authorization.
 $SP_FILE = $MODULE.'/view/' . $App->view . '.php';
@@ -206,7 +207,7 @@ if (file_exists($SP_FILE)) {
     }
     else {
         // authzError
-        $App->log("ERR_AUTHZ $SP_FILE",0,'SPAF2','SPAF2');
+        $App->log("ERR_AUTHZ[$ACCESS_LEVEL] $SP_FILE",0,'SPAF2','SPAF2');
         $App->view = 'error';
     }
 }
@@ -220,7 +221,7 @@ if (file_exists($MODULE.'/post_view.php')) {
 /* Check template authorization */
 if ($App->getConfig('TEMPLATE_AUTHZ',true) &! $App->authz($App->view)) {
     // authzError
-    $App->log("ERR_AUTHZ Template: $App->view.tpl",0,'SPAF2');
+    $App->log("ERR_AUTHZ[$ACCESS_LEVEL] Template: $App->view.tpl",0,'SPAF2');
     $App->view = 'error';
 }
 
@@ -228,7 +229,7 @@ if ($App->getConfig('TEMPLATE_AUTHZ',true) &! $App->authz($App->view)) {
 $App->tplConfig();
 
 $App->assign('USER',$USER);
-$App->assign('ACCESS_LEVEL',$App->accessLevel());
+$App->assign('ACCESS_LEVEL',$ACCESS_LEVEL);
 $App->assign('CA',$App->getparam('CA'));
 $App->assign('DEBUG',$App->DEBUG);
 $App->assign('LOCALE_TXT',$App->locale_txt);
@@ -240,7 +241,7 @@ if ($App->getParam('SKIN')) {
     $App->setSkin($App->getParam('SKIN'));
 }
 
-$App->log("TPL $App->view",2,'SPAF2');
+$App->log("TPL[$ACCESS_LEVEL] $App->view",2,'SPAF2');
 $App->template = $App->view;
 // header and footer relative to template_root
 $App->compile($App->TPL->getTemplateDir(0).'/'.$header_template);
