@@ -67,7 +67,7 @@ class ApplicationConfig
      * @param string $configdir
      * @return object
      */
-    function ApplicationConfig ($configdir)
+    function __construct($configdir)
     {
         $this->configdir = $configdir;
         $this->parameters = array(); 
