@@ -84,7 +84,11 @@ catch (Exception $e) {
 
 // LOGIN SUCCESSFUL
 $App->log('Authentication of '.$USER->id. ' successful',1);
-$App->setSession('DISABLED',$App->getConfigList('INFO_DISABLED',array()));
+$info_disabled = $App->getConfigList('INFO_DISABLED',array());
+if (in_array('SYSDATA',$info_disabled)) {
+    $USER->unsetPermission('SYSDATA');
+}
+$App->setSession('DISABLED',$info_disabled);
 
 // initialize backend
 $FilterList = Filter::FetchList($USER);
@@ -92,6 +96,9 @@ $filterString = '';
 foreach ($FilterList as $Filter) {
     $filterString .= $Filter->getString();
 }
+if ($USER->getRole() == 'REVISOR') {
+    $filterString = '*';
+}
 
 $rest_data = $USER->getRestData();
 $Backend = new Backend($rest_data['URL'],$rest_data['USER'],$rest_data['PASS'],
