@@ -47,8 +47,8 @@ catch (Exception $e) {
 
 $filterString = "(id:*)";
 
-if ($App->getConfig('PERMALINK_UNAUTHENTICATED') != 'yes') {
-    $App->redirect('index.php?CA=default',array('id' => $permalink));
+if (!$App->getConfig('PERMALINK_UNAUTHENTICATED')) {
+    $App->redirect('index.php?CA=permaLink',array('id' => $permalink));
 }
 
 
