@@ -34,7 +34,7 @@
 $sessionMailId = $App->getParam('id');
 
 try {
-    $EMail = $Backend->fetch($sessionMailId);
+    $EMail = $Backend->fetch($archive,$sessionMailId);
 }
 catch (Exception $e) {
     $App->log('[printMail] '.$e->getMessage());
