@@ -53,7 +53,7 @@ if ($_sortOrder = $App->getParam('select_nachricht')) {
 $Query->setSortOrder($sortOrder);
 
 try {
-    $QueryResult = $Backend->query($Query,$startNum,$search_limit);
+    $QueryResult = $Backend->query($archive,$Query,$startNum,$search_limit);
     $sessionMailId = $QueryResult->getSessionMailId(0);
 }
 catch (Exception $e) {
