@@ -31,14 +31,14 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 
-// DB hook
 require_once 'model/AppState.php';
 
-$userList = array();
 foreach ($USER->getArchives() as $archive) {
     $users = User::FetchList($archive);
-    if (!empty($users)) {
-        $userList = array_merge($userList, $users);
+
+    foreach($users as $userid => $userobj) {
+        if ($userobj->id == '') { continue; }  // skip empty
+        $userList[$userid] = $userobj;
     }
 }
 
