@@ -35,7 +35,7 @@
 $currentCookieParams = session_get_cookie_params();
 	session_set_cookie_params(
 		$currentCookieParams["lifetime"],
-		$_SERVER['SCRIPT_NAME'],
+		dirname($_SERVER['SCRIPT_NAME']),
 		$currentCookieParams["secure"],
 		$currentCookieParams["httponly"]
 		);
