@@ -52,8 +52,8 @@ class Benno
      */
     function __construct()
     {
-        $this->infoText = 'Benno MailArchiv Version 2.8.9-2'; 
-        $this->buildInfo= '201210160616/333f5bd';
+        $this->infoText = 'Benno MailArchiv Version 2.8.10'; 
+        $this->buildInfo= '201214160116/e4c9313';
         $this->buildYear= '2020';
     }
 
