@@ -105,6 +105,10 @@ class License
     var $restVersion;
 
 
+    /**
+     * licenseInstanceId
+     */
+    var $licenseInstanceId;
 
 
     /**
@@ -112,7 +116,8 @@ class License
      *
      * @access public
      */
-    function __construct($licenseStatus,$licenseExpires,$licenseType,$licenseFile,$address,$hostname,$containerCount,$coreVersion,$restVersion)
+    function __construct($licenseStatus,$licenseExpires,$licenseType,$licenseFile,$address,$hostname,
+                         $containerCount,$coreVersion,$restVersion,$licenseInstanceId)
     {
 
         if (preg_match('/^LICENSE_VALID/',$licenseStatus)) {
@@ -136,6 +141,8 @@ class License
         $this->coreVersion = $coreVersion;
         $this->restVersion = $restVersion;
 
+        $this->licenseInstanceId = $licenseInstanceId;
+
         $lines = preg_split('/\n/',$licenseFile);
         foreach ($lines as $line) {
 
@@ -164,5 +171,17 @@ class License
         
         return $ret;
     }
+
+
+    function isTestperiod()
+    {
+        global $App;
+
+        if (preg_match('/TESTPERIOD/',$licenseStatus)) {
+            return true;
+        }
+        return false;
+    }
+
 }
 ?>
