@@ -55,11 +55,12 @@ class QueryResult
     var $Query;        // Query object
 
 
-    function QueryResult ($resultList,$Query,$limit)
+    function __construct($resultList,$Query,$limit)
     {
         global $App;
 
         if (!is_array($resultList)) {
+            $resultList = [];
             $resultList['first'] = -1;
             $resultList['last']  = -1;
             $resultList['limit'] = -1;
