@@ -390,6 +390,9 @@ class UserDA extends Persistence
                 case 'WARN':
                     $App->log('WARN '.$data,0);
                     break;
+                case 'NOTE':
+                    // only for cmdline debugging
+                    break;
                 case 'ROLE':
                     $this->role = $data;
                     break;
