@@ -56,8 +56,8 @@ if (preg_match('/^\/login\/?$/',$_SERVER['PATH_INFO'])) {
     require 'view/rest_auth.php';       // exit in view/rest_auth.php
 }
 
-$User = $App->getSession('USER');
-if (!$User) {
+$USER = $App->getSession('USER');
+if (!$USER) {
     $message = 'Request not authenticated.';
     auth_exit($message);
 }
