@@ -31,7 +31,5 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 
-
-$App->assign('LAST_ACTION',$App->getSession('LAST_ACTION'));
-
+$App->redirect('default', array('MSG' => 'ERR_AUTHZ'));
 ?>
